print("import: 'flask_cors'")
import flask_cors

print("import: 'flask_cors.core'")
import flask_cors.core

print("import: 'flask_cors.decorator'")
import flask_cors.decorator

print("import: 'flask_cors.extension'")
import flask_cors.extension

print("import: 'flask_cors.version'")
import flask_cors.version

